import axios from 'axios'
import qs from 'qs' // eslint-disable-line no-unused-vars
import {Message} from 'element-ui'
import router from '../router'

// axios 配置
axios.defaults.baseURL = '/apis/'
// axios.defaults.baseURL = 'https://www.cnd3b.com/samex/rest/webclientrest'
// axios.defaults.baseURL = 'http://121.37.152.76:8080/samex/rest/webclientrest' //测试地址
axios.defaults.timeout = 30000
axios.defaults.headers.post['Content-Type'] = 'application/octet-stream'

axios.defaults.withCredentials = true

// const CancelToken = axios.CancelToken;
// const source = CancelToken.source();

function getLog (url,status,message) {
  let date = new Date()
  let now = date.getFullYear() +'-'+ date.getMonth()+1+'-'+date.getDate() +':'+ date.getHours() + ':' + date.getMinutes() + ':'+date.getSeconds()
  let obj = {
    error_time:now,
    error_code:status,
    error_url:url,
    error_message:message === 'Network Error'?'数据请求异常':message
  } // eslint-disable-line no-unused-vars
  Message.error({message: obj.error_message,offset:100});
}
// 请求拦截器
axios.interceptors.request.use(config => {
  // config.cancelToken = source.token;
  return config
}, error => {
  return Promise.reject(error)
})

// 异常处理
axios.interceptors.response.use(response => {
  // if ( response.data.errcode === '005') {
  //     source.cancel(); // 取消其他正在进行的请求
  //     // some coding
  // }
  return {
    code: response.status,
    message: response.statusText,
    data: response.data
  }
}, err => {
  if (err && err.response) {
    switch (err.response.status) {
      case 400:
        err.status = 400
        err.message = '错误请求'
        break
      case 401:
        err.status = 401
        err.message = '未授权，请重新登录'
        break
      case 403:
        err.status = 403
        err.message = '拒绝访问'
        break
      case 404:
        err.status = 404
        err.message = '请求错误,未找到该资源'
        break
      case 405:
        err.status = 405
        err.message = '请求方法未允许'
        break
      case 408:
        err.status = 408
        err.message = '请求超时'
        break
      case 500:
        err.status = 500
        err.message = '服务器端出错'
        break
      case 501:
        err.status = 501
        err.message = '网络未实现'
        break
      case 502:
        err.status = 502
        err.message = '网络错误'
        break
      case 503:
        err.status = 503
        err.message = '服务不可用'
        break
      case 504:
        err.status = 504
        err.message = '网络超时'
        break
      case 505:
        err.status = 505
        err.message = 'http版本不支持该请求'
        break
      default:
        err.message = `连接错误${err.response.status}`
    }
  }
  if (axios.isCancel(err)) { // 取消请求的情况下，终端Promise调用链
      return new Promise(() => {});
  } else {
      return Promise.reject(err);
  }
})

export function fetchPost (url,classname,method, params) {
  if (!params) {
    params = {}
  }
  return new Promise((resolve, reject) => {
    let param = {}
    if (url === 'login' || url === 'getpassword' || url === 'loginbyaccount') {
      param = params
    } else {
      param = {
        accesstoken:sessionStorage.getItem('token'),
        classname:classname,
        method:method,
        content: params
      }
    } // 验证是否为登陆
    axios.post(url, param).then((response) => {
      function success () {
        resolve(response.data)
      }
      function failed () {
        // 接口异常处理
        resolve(response.data)
        let msg = response.data.data?response.data.msg + ':' + response.data.data:response.data.msg
        switch (response.data.errcode) {
          case '005':
            // Message.error({message: '登录信息过期,请重新登录!',offset:100})
            localStorage.clear()
            router.push({path:'/'})
            setTimeout(() => {
              location.reload();
            }, 1000);
          break
          default:
            Message.error({message: msg,offset:100})
        }
      }
      response.data.code === 1?success():failed()
    })
    .catch((error) => {
      getLog(url,error.status,error.message)
      reject(error)
    })
  })
}

export default {
  userLogin (userLogin) {
    return fetchPost('login','','', userLogin)
  },
  loginbyaccount (loginbyaccount) {
    return fetchPost('loginbyaccount','','', loginbyaccount)
  },
  getPassword (getPassword) {
    return fetchPost('getpassword','','', getPassword)
  },
  changePassWordApi (changePassWord) {
    return fetchPost('','system.users.Users','changePassWord', changePassWord)
  },
  getFileNameApi (getFileName) {
    return fetchPost('','system.system.docManage','getFileName', getFileName)
  },
  queryBriefreportApi (queryBriefreportApi) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_briefreport', queryBriefreportApi)
  },
  queryEnterpriseMain (queryEnterpriseMain) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_enterpriseMain', queryEnterpriseMain)
  },
  queryEnterpriseUsers (queryEnterpriseUsers) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_enterpriseUsers', queryEnterpriseUsers)
  },
  queryEnterpriseAgents (queryEnterpriseAgents) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_agentusers', queryEnterpriseAgents)
  },
  query_enterpriseUserApi (query_enterpriseUser) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_enterpriseUser', query_enterpriseUser)
  },
  updateEnterpriseUsers (updateEnterpriseUsers) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'update_enterpriseUsers', updateEnterpriseUsers)
  },
  updateBasicInformation (updateEnterpriseUsers) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'update_enterpriseMain', updateEnterpriseUsers)
  },
  queryEnterpriseVars (queryEnterpriseVars) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_enterpriseVars', queryEnterpriseVars)
  },
  queryEnterpriseAgentsList (queryEnterpriseAgentsList) {
    return fetchPost('','webclient.tagents.tagents', 'query_enterpriseAgentsList', queryEnterpriseAgentsList)
  },
  querySaleruserid (querySaleruserid) {
    return fetchPost('','webclient.tagents.tagents', 'query_saleruserid', querySaleruserid)
  },
  insertModifyEnterpriseAgent (insertModifyEnterpriseAgent) {
    return fetchPost('','webclient.tagents.tagents', 'insert_modify_enterpriseAgent', insertModifyEnterpriseAgent)
  },
  deleteAgent (deleteAgent) {
    return fetchPost('','webclient.tagents.tagents', 'delete_enterpriseAgent', deleteAgent) 
  },
  queryEnterpriseAgentsMain (queryEnterpriseAgentsMain) {
    return fetchPost('','webclient.tagents.tagents', 'query_enterpriseAgentsMain', queryEnterpriseAgentsMain)
  },
  queryEnterpriseAgentUsers (queryEnterpriseAgentUsers) {
    return fetchPost('','webclient.tagents.tagents', 'query_enterpriseAgentUsers', queryEnterpriseAgentUsers)
  },
  queryAgentStoreList (queryAgentStoreList) {
    return fetchPost('','webclient.tstore.tstore', 'query_AgentStoreList', queryAgentStoreList)
  },
  queryStorestatusList (queryStorestatusList) {
    return fetchPost('','webclient.tstore.tstore', 'query_storestatusList', queryStorestatusList)
  },
  queryStoretypeList (queryStoretypeList) {
    return fetchPost('','webclient.tstore.tstore', 'query_storetypeList', queryStoretypeList)
  },
  queryMarketList (queryMarketList) {
    return fetchPost('','webclient.tstore.tstore', 'query_marketList', queryMarketList)
  },
  storeInsertOrModify (storeInsertOrModify) {
    return fetchPost('','webclient.tstore.tstore', 'storeInsertOrModify', storeInsertOrModify)
  },
  queryStoreMain (queryStoreMain) {
    return fetchPost('','webclient.tstore.tstore', 'query_storeMain', queryStoreMain)
  },
  deleteShop (deleteShop) {
    return fetchPost('','webclient.tstore.tstore', 'storeDelete', deleteShop)
  },
  queryDoc (queryDoc) {
    return fetchPost('','system.system.docManage', 'queryDoc', queryDoc)    
  },
  deleteDoc (deleteDoc) {
    return fetchPost('','system.system.docManage', 'deleteDoc', deleteDoc)
  },
  storeRebuild (storeRebuild) {
    return fetchPost('','webclient.tstore.tstore', 'storeRebuild', storeRebuild)
  },
  queryCustomer (queryCustomer) {
    return fetchPost('','webclient.tagents.tagents', 'query_customer', queryCustomer)
  },
  queryCustomerReception (queryCustomerReception) {
    return fetchPost('','webclient.tagents.tagents', 'query_customer_reception', queryCustomerReception)
  },
  queryCustactionlList (queryCustactionlList) {
    return fetchPost('','webclient.system.custaction', 'query_custactionlList', queryCustactionlList)
  },
  insertModifyCustaction (insertModifyCustaction) {
    return fetchPost('','webclient.system.custaction', 'insert_modify_custaction', insertModifyCustaction)
  },
  deleteCustaction (deleteCustaction) {
    return fetchPost('','webclient.system.custaction', 'delete_custaction', deleteCustaction)
  },
  queryChannelList (queryChannelList) {
    return fetchPost('','webclient.system.channel', 'query_channelList', queryChannelList)
  },
  insertModifyChannel (insertModifyChannel) {
    return fetchPost('','webclient.system.channel', 'insert_modify_channel', insertModifyChannel)
  },
  deleteChannel (deleteChannel) {
    return fetchPost('','webclient.system.channel', 'delete_channel', deleteChannel)
  },
  queryStandardworkList (queryStandardworkList) {
    return fetchPost('','webclient.system.standardwork', 'query_standardworkList', queryStandardworkList)
  },
  insertModifyStandardwork (insertModifyStandardwork) {
    return fetchPost('','webclient.system.standardwork', 'insert_modify_standardwork', insertModifyStandardwork)
  },
  deleteStandardworkList (deleteStandardworkList) {
    return fetchPost('','webclient.system.standardwork', 'delete_standard', deleteStandardworkList)
  },
  queryBusinesstripList (queryBusinesstripList) {
    return fetchPost('','webclient.businesstrip.businesstrip', 'query_businesstripList', queryBusinesstripList)
  },
  queryBusinesstripMain (queryBusinesstripMain) {
    return fetchPost('','webclient.businesstrip.businesstrip', 'query_businesstripMain', queryBusinesstripMain)
  },
  updateGrade (updateGrade) {
    return fetchPost('','webclient.businesstrip.businesstrip', 'updateGrade', updateGrade)
  },
  businesstripDelete(businesstripDelete){
    return fetchPost('','webclient.businesstrip.businesstrip', 'businesstripDelete', businesstripDelete)
  },
  querySaleList (querySaleList) {
    return fetchPost('','webclient.saleinput.saleinput', 'query_saleList', querySaleList)
  },
  saleDelete (saleDelete) {
    return fetchPost('','webclient.saleinput.saleinput', 'saleDelete', saleDelete)
  },
  queryAgentList (queryAgentList) {
    return fetchPost('','webclient.saleinput.saleinput', 'query_agentList', queryAgentList)
  },
  saleInsertOrModify (saleInsertOrModify) {
    return fetchPost('','webclient.saleinput.saleinput', 'saleInsertOrModify', saleInsertOrModify)
  },
  queryArchivesList (queryArchivesList) {
    return fetchPost('','webclient.archives.archives', 'query_archivesList', queryArchivesList)
  },
  queryDocMain (queryDocMain) {
    return fetchPost('','webclient.archives.archives', 'query_archivesMain', queryDocMain)
  },
  queryDocList (queryDocList) {
    return fetchPost('','system.system.docManage', 'queryDoc', queryDocList)
  },
  getArchivesClass (getArchivesClass) {
    return fetchPost('','webclient.archives.archives', 'getArchivesClass', getArchivesClass)
  },
  archivesInsertOrModify (archivesInsertOrModify) {
    return fetchPost('','webclient.archives.archives', 'archivesInsertOrModify', archivesInsertOrModify)
  },
  archivesCheck (archivesCheck) {
    return fetchPost('','webclient.archives.archives', 'archivesCheck', archivesCheck)
  },
  archiveDelete (archiveDelete) {
    return fetchPost('','webclient.archives.archives', 'archiveDelete', archiveDelete)
  },
  saleAmountGrowthRateAnalysis (saleAmountGrowthRateAnalysis) {
    return fetchPost('','webclient.data.analysis', 'saleAmountGrowthRateAnalysis', saleAmountGrowthRateAnalysis)
  },
  saleAmountAverageAnalysis (saleAmountAverageAnalysis) {
    return fetchPost('','webclient.data.analysis', 'saleAmountAverageAnalysis', saleAmountAverageAnalysis)
  },
  saleAmountAnalysis (saleAmountAnalysis) {
    return fetchPost('','webclient.data.analysis', 'saleAmountAnalysis', saleAmountAnalysis)
  },
  storeAreaAnalysis (storeAreaAnalysis) {
    return fetchPost('','webclient.data.analysis', 'storeAreaAnalysis', storeAreaAnalysis)
  },
  storeRebuildAnalysis (storeRebuildAnalysis) {
    return fetchPost('','webclient.data.analysis', 'storeRebuildAnalysis', storeRebuildAnalysis)
  },
  storeMarketAnalysis (storeMarketAnalysis) {
    return fetchPost('','webclient.data.analysis', 'storeMarketAnalysis', storeMarketAnalysis)
  },
  channelofcustomers (channelofcustomers) {
    return fetchPost('','webclient.data.analysis', 'channelofcustomers', channelofcustomers)
  },
  newcustomers (newcustomers) {
    return fetchPost('','webclient.data.analysis', 'newcustomers', newcustomers)
  },
  customeraction (customeraction) {
    return fetchPost('','webclient.data.analysis', 'customeraction', customeraction)
  },
  channeloforders (channeloforders) {
    return fetchPost('','webclient.data.analysis', 'channeloforders', channeloforders)
  },
  productoforders (productoforders) {
    return fetchPost('','webclient.data.analysis', 'productoforders', productoforders)
  },
  amountoforders (amountoforders) {
    return fetchPost('','webclient.data.analysis', 'amountoforders', amountoforders)
  },
  communityoforders (communityoforders) {
    return fetchPost('','webclient.data.analysis', 'communityoforders', communityoforders)
  },
  returncountoforders (returncountoforders) {
    return fetchPost('','webclient.data.analysis', 'returncountoforders', returncountoforders)
  },
  customeroforders (customeroforders) {
    return fetchPost('','webclient.data.analysis', 'customeroforders', customeroforders)
  },
  eventoforders (eventoforders) {
    return fetchPost('','webclient.data.analysis', 'eventoforders', eventoforders)
  },
  costnameofmonth (costnameofmonth) {
    return fetchPost('','webclient.data.analysis', 'costnameofmonth', costnameofmonth)
  },
  costandordersofmonth (costandordersofmonth) {
    return fetchPost('','webclient.data.analysis', 'costandordersofmonth', costandordersofmonth)
  },
  oldcustomer (oldcustomer) {
    return fetchPost('','webclient.data.analysis', 'oldcustomer', oldcustomer)
  },
  newcustomer (newcustomer) {
    return fetchPost('','webclient.data.analysis', 'newcustomer', newcustomer)
  },
  receptiontimesoffirstorder (receptiontimesoffirstorder) {
    return fetchPost('','webclient.data.analysis', 'receptiontimesoffirstorder', receptiontimesoffirstorder)
  },
  businesstripGrade (businesstripGrade) {
    return fetchPost('','webclient.data.analysis', 'businesstripGrade', businesstripGrade)
  },
  businesstripGetKnowledge (businesstripGetKnowledge) {
    return fetchPost('','webclient.data.analysis', 'businesstripGetKnowledge', businesstripGetKnowledge)
  },
  agentsoforders (agentsoforders) {
    return fetchPost('','webclient.data.analysis', 'agentsoforders', agentsoforders)
  },
  eventofagentorders (eventofagentorders) {
    return fetchPost('','webclient.data.analysis', 'eventofagentorders', eventofagentorders)
  },
  // 标准版接口
  apprequesttimesApi (apprequesttimes) {
    return fetchPost('','webclient.data.analysis', 'apprequesttimes', apprequesttimes)
  },
  apprequesttimesbydayApi (apprequesttimesbyday) {
    return fetchPost('','webclient.data.analysis', 'apprequesttimesbyday', apprequesttimesbyday)
  },
  userrequestcountApi (userrequestcount) {
    return fetchPost('','webclient.data.analysis', 'userrequestcount', userrequestcount)
  },
  userdownloadcountApi (userdownloadcount) {
    return fetchPost('','webclient.data.analysis', 'userdownloadcount', userdownloadcount)
  },
  simplebriefreportApi (simplebriefreport) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_simplebriefreport', simplebriefreport)
  },
  queryOrModifyApi (queryOrModify) {
    return fetchPost('','webclient.phonebook.phonebook', 'query', queryOrModify)
  },
  insertOrModifyApi (insertOrModify) {
    return fetchPost('','webclient.phonebook.phonebook', 'insertOrModify', insertOrModify)
  },
  deleteOrModifyApi (deleteOrModify) {
    return fetchPost('','webclient.phonebook.phonebook', 'delete', deleteOrModify)
  },
  submiteditInsertOrModifyApi (submiteditInsertOrModify) {
    return fetchPost('','webclient.submitedit.submitedit', 'insertOrModify', submiteditInsertOrModify)
  },
  querySubmiteditmodelListApi (querysubmiteditmodelList) {
    return fetchPost('','webclient.submitedit.submitedit', 'query_submiteditmodelList', querysubmiteditmodelList)
  },
  submitEditcheckApi (submitEditcheck) {
    return fetchPost('','webclient.submitedit.submitedit', 'check', submitEditcheck)
  },
  submitEditDeleteApi (submitEditDelete) {
    return fetchPost('','webclient.submitedit.submitedit', 'delete', submitEditDelete)
  },
  querySubmiteditListApi (query_submiteditList) {
    return fetchPost('','webclient.submitedit.submitedit', 'query_submiteditList', query_submiteditList)
  },
  returneditApi (returnedit) {
    return fetchPost('','webclient.submitedit.submitedit', 'returnedit', returnedit)
  },
  noticeInsertOrModifyApi (insertOrModify) {
    return fetchPost('','webclient.notice.notice', 'insertOrModify', insertOrModify)
  },
  queryNoticeListApi (queryNoticeListApi) {
    return fetchPost('','webclient.notice.notice', 'query_noticeList', queryNoticeListApi)
  },
  queryMoticeMainApi (queryMoticeMainApi) {
    return fetchPost('','webclient.notice.notice', 'query_noticeMain', queryMoticeMainApi)
  },
  deleteNoticeApi (deleteNotice) {
    return fetchPost('','webclient.notice.notice', 'delete', deleteNotice)
  },
  checkNoticeApi (checkNoticeApi) {
    return fetchPost('','webclient.notice.notice', 'check', checkNoticeApi)
  },
  queryNoticeLeavemessageListApi (queryNoticeLeavemessageListApi) {
    return fetchPost('','webclient.notice.notice', 'query_noticeLeavemessageList', queryNoticeLeavemessageListApi)
  },
  queryUsergroupListApi (queryusergroupList) {
    return fetchPost('','webclient.usergroup.usergroup', 'query_usergroupList', queryusergroupList)
  },
  insertOrModifyMainApi (insertOrModifyMain) {
    return fetchPost('','webclient.usergroup.usergroup', 'insertOrModifyMain', insertOrModifyMain)
  },
  deleteGroupApi (deleteGroup) {
    return fetchPost('','webclient.usergroup.usergroup', 'delete', deleteGroup)
  },
  queryGroupnameListApi (query_groupnameList) {
    return fetchPost('','webclient.phonebook.phonebook', 'query_groupnameList', query_groupnameList)
  },
  insertModifyGroupnameApi (insertModifyGroupname) {
    return fetchPost('','webclient.phonebook.phonebook', 'insert_modify_groupname', insertModifyGroupname)
  },
  deleteGroupnameApi (delete_groupname) {
    return fetchPost('','webclient.phonebook.phonebook', 'delete_groupname', delete_groupname)
  },
  queryComplaintApi (queryComplaintApi) {
    return fetchPost('','webclient.complaint.complaint', 'query', queryComplaintApi)
  },
  updateComplaintApi (updateComplaintApi) {
    return fetchPost('','webclient.complaint.complaint', 'update', updateComplaintApi)
  },
  addusergroupApi (addusergroup) {
    return fetchPost('','webclient.notice.notice', 'addusergroup', addusergroup)
  },
  queryNoticeuserListApi (query_noticeuserList) {
    return fetchPost('','webclient.notice.notice', 'query_noticeuserList', query_noticeuserList)
  },
  deleteNoticeuserApi (deleteNoticeuser) {
    return fetchPost('','webclient.notice.notice', 'deleteuser', deleteNoticeuser)
  },
  queryUsergroupMainApi (queryUsergroupMain) {
    return fetchPost('','webclient.usergroup.usergroup', 'query_usergroupMain', queryUsergroupMain)
  },
  queryUsergroupDetailApi (queryUsergroupDetail) {
    return fetchPost('','webclient.usergroup.usergroup', 'query_usergroupDetail', queryUsergroupDetail)
  },
  queryAllusersApi (queryAllusers) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_allusers', queryAllusers)
  },
  insertusersApi (insertusers) {
    return fetchPost('','webclient.usergroup.usergroup', 'insertusers', insertusers)
  },
  deleteusersApi (deleteusers) {
    return fetchPost('','webclient.usergroup.usergroup', 'deleteusers', deleteusers)
  },
  query_typeListApi (query_typeList) {
    return fetchPost('','webclient.system.notice', 'query_typeList', query_typeList)
  },
  insert_modify_typeApi (insert_modify_type) {
    return fetchPost('','webclient.system.notice', 'insert_modify_type', insert_modify_type)
  },
  deleteTypeApi (deleteType) {
    return fetchPost('','webclient.system.notice', 'delete_type', deleteType)
  },
  query_complaint_typeListApi (query_complaint_typeList) {
    return fetchPost('','webclient.system.complaint', 'query_typeList', query_complaint_typeList)
  },
  insert_complaint_modify_typeApi (insert_complaint_modify_type) {
    return fetchPost('','webclient.system.complaint', 'insert_modify_type', insert_complaint_modify_type)
  },
  delete_complaint_TypeApi (delete_complaint_Type) {
    return fetchPost('','webclient.system.complaint', 'delete_type', delete_complaint_Type)
  },
  query_allusersApi (query_allusers) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'query_allusers', query_allusers)
  },
  notice_adduserApi (notice_adduser) {
    return fetchPost('','webclient.notice.notice', 'adduser', notice_adduser)
  },
  uploadSuccsessApi (uploadSuccsess) {
    return fetchPost('','system.system.docManage', 'uploadSuccsess', uploadSuccsess)
  },
  uploadSuccsessApi2 (uploadSuccsess) {
    return fetchPost('','system.system.docManage', 'uploadSuccsess2', uploadSuccsess)
  },
  queryPresentuserListApi (queryPresentuserList) {
    return fetchPost('','webclient.submitedit.submitedit', 'query_submitedituserList', queryPresentuserList)
  },
  present_adduserApi (present_adduser) {
    return fetchPost('','webclient.submitedit.submitedit', 'adduser', present_adduser)
  },
  present_addusergroupApi (present_addusergroup) {
    return fetchPost('','webclient.submitedit.submitedit', 'addusergroup', present_addusergroup)
  },
  present_deleteuserApi (present_deleteuser) {
    return fetchPost('','webclient.submitedit.submitedit', 'deleteuser', present_deleteuser)
  },
  read_analysisApi (read_analysis) {
    return fetchPost('','webclient.notice.notice', 'read_analysis', read_analysis)
  },
  read_saler_analysisApi (read_saler_analysis) {
    return fetchPost('','webclient.notice.notice', 'read_analysis_saler', read_saler_analysis)
  },
  notice_havenoreaduserlistApi (notice_havenoreaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havenoreaduserlist', notice_havenoreaduserlist)
  },
  notice_saler_havenoreaduserlistApi (notice_saler_havenoreaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havenoreaduserlist_saler', notice_saler_havenoreaduserlist)
  },
  notice_havereaduserlistApi (notice_havereaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havereaduserlist', notice_havereaduserlist)
  },
  notice_saler_havereaduserlistApi (notice_saler_havereaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havereaduserlist_saler', notice_saler_havereaduserlist)
  },
  download_analysisApi (download_analysis) {
    return fetchPost('','webclient.notice.notice', 'download_analysis', download_analysis)
  },
  download_saler_analysisApi (download_saler_analysis) {
    return fetchPost('','webclient.notice.notice', 'download_analysis_saler', download_saler_analysis)
  },
  notice_havenodownloaduserlistApi (notice_havenodownloaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havenodownloaduserlist', notice_havenodownloaduserlist)
  },
  notice_saler_havenodownloaduserlistApi (notice_saler_havenodownloaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havenodownloaduserlist_saler', notice_saler_havenodownloaduserlist)
  },
  notice_havedownloaduserlistApi (notice_havedownloaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havedownloaduserlist', notice_havedownloaduserlist)
  },
  notice_saler_havedownloaduserlistApi (notice_saler_havedownloaduserlist) {
    return fetchPost('','webclient.notice.notice', 'havedownloaduserlist_saler', notice_saler_havedownloaduserlist)
  },
  noticeontopApi (noticeontop) {
    return fetchPost('','webclient.notice.notice', 'noticeontop', noticeontop)
  },
  score_analysisApi (score_analysis) {
    return fetchPost('','webclient.notice.notice', 'score_analysis', score_analysis)
  },
  score_saler_analysisApi (score_saler_analysis) {
    return fetchPost('','webclient.notice.notice', 'score_analysis_saler', score_saler_analysis)
  },
  scorelist_analysisApi (scorelist_analysis) {
    return fetchPost('','webclient.notice.notice', 'scorelist_analysis', scorelist_analysis)
  },
  scorelist_saler_analysisApi (scorelist_saler_analysis) {
    return fetchPost('','webclient.notice.notice', 'scorelist_analysis_saler', scorelist_saler_analysis)
  },
  submitedit_havenoreaduserlistApi (submitedit_havenoreaduserlist) {
    return fetchPost('','webclient.submitedit.submitedit', 'havenoreaduserlist', submitedit_havenoreaduserlist)
  },
  submitedit_havereaduserlistApi (submitedit_havereaduserlist) {
    return fetchPost('','webclient.submitedit.submitedit', 'havereaduserlist', submitedit_havereaduserlist)
  },
  submit_analysisApi (submit_analysis) {
    return fetchPost('','webclient.submitedit.submitedit', 'submit_analysis', submit_analysis)
  },
  archives_read_analysisApi (archives_read_analysis ) {
    return fetchPost('','webclient.archives.archives', 'read_analysis', archives_read_analysis)
  },
  archives_read_saler_analysisApi (archives_read_saler_analysis ) {
    return fetchPost('','webclient.archives.archives', 'read_analysis_saler', archives_read_saler_analysis)
  },
  archives_havenoreaduserlistApi (archives_havenoreaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havenoreaduserlist', archives_havenoreaduserlist)
  },
  archives_saler_havenoreaduserlistApi (archives_saler_havenoreaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havenoreaduserlist_saler', archives_saler_havenoreaduserlist)
  },
  archives_havereaduserlistApi (archives_havereaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havereaduserlist', archives_havereaduserlist)
  },
  archives_saler_havereaduserlistApi (archives_saler_havereaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havereaduserlist_saler', archives_saler_havereaduserlist)
  },
  archives_download_analysisApi (archives_download_analysis) {
    return fetchPost('','webclient.archives.archives', 'download_analysis', archives_download_analysis)
  },
  archives_download_saler_analysisApi (archives_download_saler_analysis) {
    return fetchPost('','webclient.archives.archives', 'download_analysis_saler', archives_download_saler_analysis)
  },
  archives_havenodownloaduserlistApi (archives_havenodownloaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havenodownloaduserlist', archives_havenodownloaduserlist)
  },
  archives_saler_havenodownloaduserlistApi (archives_saler_havenodownloaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havenodownloaduserlist_saler', archives_saler_havenodownloaduserlist)
  },
  archives_havedownloaduserlistApi (archives_havedownloaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havedownloaduserlist', archives_havedownloaduserlist)
  },
  archives_saler_havedownloaduserlistApi (archives_saler_havedownloaduserlist) {
    return fetchPost('','webclient.archives.archives', 'havedownloaduserlist_saler', archives_saler_havedownloaduserlist)
  },
  query_onlineuserlistApi (query_onlineuserlist) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_onlineuserlist', query_onlineuserlist)
  },
  query_todayhaventrequestagentlistApi (query_todayhaventrequestagentlist) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_todayhaventrequestagentlist', query_todayhaventrequestagentlist)
  },
  query_todayrequestagentlistApi (query_todayrequestagentlist) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_todayrequestagentlist', query_todayrequestagentlist)
  },
  query_todaydownloadlistApi (query_todaydownloadlist) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_todaydownloadlist', query_todaydownloadlist)
  },
  query_noticeanalysisApi (query_noticeanalysis) {
    return fetchPost('','webclient.notice.notice', 'analysis', query_noticeanalysis)
  },
  query_systemappsApi (query_systemapps) {
    return fetchPost('','webclient.system.authgroup', 'query_systemapps', query_systemapps)
  },
  insert_modify_tauthgroupApi (insert_modify_tauthgroup) {
    return fetchPost('','webclient.system.authgroup', 'insert_modify_tauthgroup', insert_modify_tauthgroup)
  },
  query_authgrouplistApi (query_authgrouplist) {
    return fetchPost('','webclient.system.authgroup', 'query_authgrouplist', query_authgrouplist)
  },
  query_administratorApi (query_administrator) {
    return fetchPost('','webclient.system.authgroup', 'query_administrator', query_administrator)
  },
  query_tauthgroupMainApi (query_tauthgroupMain) {
    return fetchPost('','webclient.system.authgroup', 'query_tauthgroupMain', query_tauthgroupMain)
  },
  authgroupDeleteApi (authgroupDelete) {
    return fetchPost('','webclient.system.authgroup', 'authgroupDelete', authgroupDelete)
  },
  modify_administratorApi (modify_administrator) {
    return fetchPost('','webclient.system.authgroup', 'modify_administrator', modify_administrator)
  },
  query_myappauthApi (query_myappauth) {
    return fetchPost('','webclient.system.authgroup', 'query_myappauth', query_myappauth)    
  },
  complaint_analysisApi (complaint_analysis) {
    return fetchPost('','webclient.complaint.complaint', 'complaint_analysis', complaint_analysis) 
  },
  complainttype_analysisApi (complainttype_analysis) {
    return fetchPost('','webclient.complaint.complaint', 'complainttype_analysis', complainttype_analysis) 
  },
  query_obsVolumeApi (query_obsVolume) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_obsVolume', query_obsVolume) 
  },
  query_smsVolumeApi (query_smsVolume) {
    return fetchPost('','webclient.mainpage.mainpage', 'query_smsVolume', query_smsVolume) 
  },
  query_archivesclassListApi (query_archivesclassList) {
    return fetchPost('','webclient.system.archivesclass', 'query_archivesclassList', query_archivesclassList) 
  },
  insert_modify_archivesclassApi (insert_modify_archivesclass) {
    return fetchPost('','webclient.system.archivesclass', 'insert_modify_archivesclass', insert_modify_archivesclass)
  },
  delete_archivesclassApi (delete_archivesclass) {
    return fetchPost('','webclient.system.archivesclass', 'delete_archivesclass', delete_archivesclass)
  },
  setDefaultPasswordApi (setDefaultPassword) {
    return fetchPost('','webclient.tenterprise.tenterprise', 'setDefaultPassword', setDefaultPassword)
  },
  query_archivesList_adApi (query_archivesList_ad) {
    return fetchPost('','webclient.archives.archives_ad', 'query_archivesList', query_archivesList_ad)
  },
  archiveDelete_adApi (archiveDelete) {
    return fetchPost('','webclient.archives.archives_ad', 'archiveDelete', archiveDelete)
  },
  getArchivesClass_adApi (getArchivesClass) {
    return fetchPost('','webclient.archives.archives_ad', 'getArchivesClass', getArchivesClass)
  },
  archivesInsertOrModify_adApi (archivesInsertOrModify) {
    return fetchPost('','webclient.archives.archives_ad', 'archivesInsertOrModify', archivesInsertOrModify)
  },
  query_archivesclassList_adApi (query_archivesclassList_ad) {
    return fetchPost('','webclient.system.archivesclass_ad', 'query_archivesclassList', query_archivesclassList_ad)
  },
  insert_modify_archivesclass_adApi (insert_modify_archivesclass_ad) {
    return fetchPost('','webclient.system.archivesclass_ad', 'insert_modify_archivesclass', insert_modify_archivesclass_ad)
  },
  delete_archivesclass_adApi (delete_archivesclass_ad) {
    return fetchPost('','webclient.system.archivesclass_ad', 'delete_archivesclass', delete_archivesclass_ad)
  },
  query_tagListApi (query_tagList) {
    return fetchPost('','webclient.system.archivestag_ad', 'query_tagList', query_tagList)
  },
  insert_modify_tagApi (insert_modify_tag) {
    return fetchPost('','webclient.system.archivestag_ad', 'insert_modify_tag', insert_modify_tag)
  },
  delete_tagApi (delete_tag) {
    return fetchPost('','webclient.system.archivestag_ad', 'delete_tag', delete_tag)
  },
  archiveDeleteApi (archiveDelete) {
    return fetchPost('','webclient.archives.archives_ad', 'archiveDelete', archiveDelete)
  },
  archivesCheckApi (archivesCheck) {
    return fetchPost('','webclient.archives.archives_ad', 'archivesCheck', archivesCheck)
  },
  query_archivesMainApi (query_archivesMain) {
    return fetchPost('','webclient.archives.archives_ad', 'query_archivesMain', query_archivesMain)
  },
  archives_ad_download_analysisApi (archives_ad_download_analysis) {
    return fetchPost('','webclient.archives.archives_ad', 'download_analysis', archives_ad_download_analysis)
  },
  archives_ad_saler_download_analysisApi (archives_ad_saler_download_analysis) {
    return fetchPost('','webclient.archives.archives_ad', 'download_analysis_saler', archives_ad_saler_download_analysis)
  },
  archives_ad_havenodownloaduserlistApi (archives_ad_havenodownloaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havenodownloaduserlist', archives_ad_havenodownloaduserlist)
  },
  archives_ad_saler_havenodownloaduserlistApi (archives_ad_saler_havenodownloaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havenodownloaduserlist_saler', archives_ad_saler_havenodownloaduserlist)
  },
  archives_ad_havedownloaduserlistApi (archives_ad_havedownloaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'download_analysis', archives_ad_havedownloaduserlist)
  },
  archives_ad_saler_havedownloaduserlistApi (archives_ad_saler_havedownloaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havedownloaduserlist_saler', archives_ad_saler_havedownloaduserlist)
  },
  archives_ad_read_analysisApi (archives_ad_read_analysis) {
    return fetchPost('','webclient.archives.archives_ad', 'read_analysis', archives_ad_read_analysis)
  },
  archives_ad_read_saler_analysisApi (archives_ad_read_saler_analysis) {
    return fetchPost('','webclient.archives.archives_ad', 'read_analysis_saler', archives_ad_read_saler_analysis)
  },
  archives_ad_havenoreaduserlistApi (archives_ad_havenoreaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havenoreaduserlist', archives_ad_havenoreaduserlist)
  },
  archives_ad_saler_havenoreaduserlistApi (archives_ad_saler_havenoreaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havenoreaduserlist_saler', archives_ad_saler_havenoreaduserlist)
  },
  archives_ad_havereaduserlistApi (archives_ad_havereaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havereaduserlist', archives_ad_havereaduserlist)
  },
  archives_ad_saler_havereaduserlistApi (archives_ad_saler_havereaduserlist) {
    return fetchPost('','webclient.archives.archives_ad', 'havereaduserlist_saler', archives_ad_saler_havereaduserlist)
  },
  query_archivesListApi (query_archivesList) {
    return fetchPost('','webclient.archives.archives_sc', 'query_archivesList', query_archivesList)
  },
  query_archivesclassList_scApi (query_archivesclassList_sc) {
    return fetchPost('','webclient.system.archivesclass_sc', 'query_archivesclassList', query_archivesclassList_sc)
  },
  insert_modify_archivesclass_scApi (insert_modify_archivesclass_sc) {
    return fetchPost('','webclient.system.archivesclass_sc', 'insert_modify_archivesclass', insert_modify_archivesclass_sc)
  },
  delete_archivesclass_scApi (delete_archivesclass_sc) {
    return fetchPost('','webclient.system.archivesclass_sc', 'delete_archivesclass', delete_archivesclass_sc)
  },
  query_tagList_scApi (query_tagList_sc) {
    return fetchPost('','webclient.system.archivestag_sc', 'query_tagList', query_tagList_sc)
  },
  insert_modify_tag_scApi (insert_modify_tag_sc) {
    return fetchPost('','webclient.system.archivestag_sc', 'insert_modify_tag', insert_modify_tag_sc)
  },
  delete_tag_scApi (delete_tag_sc) {
    return fetchPost('','webclient.system.archivestag_sc', 'delete_tag', delete_tag_sc)
  },
  getArchivesClass_scApi (getArchivesClass_sc) {
    return fetchPost('','webclient.archives.archives_sc', 'getArchivesClass', getArchivesClass_sc)
  },
  archivesInsertOrModify_scApi (archivesInsertOrModify_sc) {
    return fetchPost('','webclient.archives.archives_sc', 'archivesInsertOrModify', archivesInsertOrModify_sc)
  },
  query_archivesMain_scApi (query_archivesMain_sc) {
    return fetchPost('','webclient.archives.archives_sc', 'query_archivesMain', query_archivesMain_sc)
  },
  archiveDelete_scApi (archiveDelete_sc) {
    return fetchPost('','webclient.archives.archives_sc', 'archiveDelete', archiveDelete_sc)
  },
  archivesCheck_scApi (archivesCheck_sc) {
    return fetchPost('','webclient.archives.archives_sc', 'archivesCheck', archivesCheck_sc)
  },
  archives_sc_read_analysisApi (archives_sc_read_analysis) {
    return fetchPost('','webclient.archives.archives_sc', 'read_analysis', archives_sc_read_analysis)
  },
  archives_sc_download_analysisApi (archives_sc_download_analysis) {
    return fetchPost('','webclient.archives.archives_sc', 'download_analysis', archives_sc_download_analysis)
  },
  archives_sc_saler_download_analysisApi (archives_sc_saler_download_analysis) {
    return fetchPost('','webclient.archives.archives_sc', 'download_analysis_saler', archives_sc_saler_download_analysis)
  },
  archives_sc_havenoreaduserlistApi (archives_sc_havenoreaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havenoreaduserlist', archives_sc_havenoreaduserlist)
  },
  archives_sc_saler_havenoreaduserlistApi (archives_sc_saler_havenoreaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havenoreaduserlist_saler', archives_sc_saler_havenoreaduserlist)
  },
  archives_sc_havereaduserlistApi (archives_sc_havereaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havereaduserlist', archives_sc_havereaduserlist)
  },
  archives_sc_saler_havereaduserlistApi(archives_sc_saler_havereaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havereaduserlist_saler', archives_sc_saler_havereaduserlist)
  },
  archives_sc_havenodownloaduserlistApi (archives_sc_havenodownloaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havenodownloaduserlist', archives_sc_havenodownloaduserlist)
  },
  archives_sc_saler_havenodownloaduserlistApi (archives_sc_saler_havenodownloaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havenodownloaduserlist_saler', archives_sc_saler_havenodownloaduserlist)
  },
  archives_sc_havedownloaduserlistApi (archives_sc_havedownloaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havedownloaduserlist', archives_sc_havedownloaduserlist)
  },
  archives_sc_saler_havedownloaduserlistApi (archives_sc_saler_havedownloaduserlist) {
    return fetchPost('','webclient.archives.archives_sc', 'havedownloaduserlist_saler', archives_sc_saler_havedownloaduserlist)
  },
  query_archives_ad_userListApi (query_archives_ad_userList) {
    return fetchPost('','webclient.archives.archives_ad', 'query_archives_ad_userList', query_archives_ad_userList)
  },
  archives_ad_addusergroupApi (archives_ad_addusergroup) {
    return fetchPost('','webclient.archives.archives_ad', 'addusergroup', archives_ad_addusergroup)
  },
  archives_ad_deleteuserApi (archives_ad_deleteuser) {
    return fetchPost('','webclient.archives.archives_ad', 'deleteuser', archives_ad_deleteuser)
  },
  archives_ad_adduserApi (archives_ad_adduser) {
    return fetchPost('','webclient.archives.archives_ad', 'adduser', archives_ad_adduser)
  },
  query_archives_sc_userListApi (query_archives_sc_userList) {
    return fetchPost('','webclient.archives.archives_sc', 'query_archives_sc_userList', query_archives_sc_userList)
  },
  archives_sc_addusergroupApi (archives_sc_addusergroup) {
    return fetchPost('','webclient.archives.archives_sc', 'addusergroup', archives_sc_addusergroup)
  },
  archives_sc_deleteuserApi (archives_sc_deleteuser) {
    return fetchPost('','webclient.archives.archives_sc', 'deleteuser', archives_sc_deleteuser)
  },
  archives_sc_adduserApi (archives_sc_adduser) {
    return fetchPost('','webclient.archives.archives_sc', 'adduser', archives_sc_adduser)
  },
  shareChannelStatisticsApi (shareChannelStatistics) {
    return fetchPost('','webclient.archives.archives_ad', 'shareChannelStatistics', shareChannelStatistics)
  },
  shareStatisticsApi (shareStatistics) {
    return fetchPost('','webclient.archives.archives_ad', 'shareStatistics', shareStatistics)
  },
  shareCustChannelStatisticsApi (shareCustChannelStatistics) {
    return fetchPost('','webclient.archives.archives_ad', 'shareCustChannelStatistics', shareCustChannelStatistics)
  },
  shareStatistics_custlistApi (shareStatistics_custlist) {
    return fetchPost('','webclient.archives.archives_ad', 'shareStatistics_custlist', shareStatistics_custlist)
  },
  archivesUnCheckApi (archivesUnCheck) {
    return fetchPost('','webclient.archives.archives_sc', 'archivesUnCheck', archivesUnCheck)
  },
  archivesUnCheck_adApi (archivesUnCheck) {
    return fetchPost('','webclient.archives.archives_ad', 'archivesUnCheck', archivesUnCheck)
  },
  archivesUnCheck_materialApi (archivesUnCheck) {
    return fetchPost('','webclient.archives.archives', 'archivesUnCheck', archivesUnCheck)
  },
  tagents_query_analysisApi (query_analysis) {
    return fetchPost('','webclient.tagents.tagents', 'query_analysis', query_analysis)
  },
  query_agenttypeListApi (query_agenttypeList) {
    return fetchPost('','webclient.system.agenttype', 'query_typeList', query_agenttypeList)
  },
  insert_modify_agenttype_typeApi (insert_modify_agenttype_type) {
    return fetchPost('','webclient.system.agenttype', 'insert_modify_type', insert_modify_agenttype_type)
  },
  delete_agenttype_typeApi (delete_agenttype_type) {
    return fetchPost('','webclient.system.agenttype', 'delete_type', delete_agenttype_type)
  },
  archives_sc_read_saler_analysisApi (archives_sc_read_saler_analysis) {
    return fetchPost('','webclient.archives.archives_sc', 'read_analysis_saler', archives_sc_read_saler_analysis)
  },
  worker_analysisApi (worker_analysis) {
    return fetchPost('','enterprise.webclient.workers.analysis', 'worker_analysis', worker_analysis)
  },
  query_agentworkerlistApi (query_agentworkerlist) {
    return fetchPost('','enterprise.webclient.workers.analysis', 'query_agentworkerlist', query_agentworkerlist)
  },
  query_submiteditListApi (query_submiteditList) {
    return fetchPost('','enterprise.webclient.workers.submitedit', 'query_submiteditList', query_submiteditList)
  },
  getForgetPasswordApi (getForgetPassword) {
    return fetchPost('','publicmethod.users.Users', 'getForgetPassword', getForgetPassword)
  },
  changePassWord2Api (changePassWord) {
    return fetchPost('','publicmethod.users.Users', 'changePassWord', changePassWord)
  },
  insert_modify_workerroleApi (insert_modify_workerrole) {
    return fetchPost('','webclient.system.workerrole', 'insert_modify_workerrole', insert_modify_workerrole)
  },
  query_workerroleListApi (query_workerroleList) {
    return fetchPost('','webclient.system.workerrole', 'query_workerroleList', query_workerroleList)
  },
  delete_workerroleApi (delete_workerrole) {
    return fetchPost('','webclient.system.workerrole', 'delete_workerrole', delete_workerrole)
  },
  customerofordersXls (customerofordersXls) {
    return fetchPost('','webclient.data.analysis', 'customerofordersXls', customerofordersXls)
  },
  changeFilesNameApi (changeFilesName) {
    return fetchPost('','system.system.docManage', 'changeFilesName', changeFilesName)
  }
}
